@@ -1,7 +1,6 @@
 from random_forest import RandomForestClassifier
 from datasource import load_data
-from cuda_decisiontree import DecisionTree
 from util import timer
 
-__version__ = "0.1.1"
+__version__ = "0.2"
 
